@@ -154,27 +154,12 @@ class ETTrainer:
         _torch.save(checkpoint, full_path)
 
     def init_experiment_cache(self):
-        r"""
-        An extra layer to reset cache for each dataspec. For example:
-        1. Set a new score to monitor:
-            self.cache['monitor_metric'] = 'Precision'
-            self.cache['metric_direction'] = 'maximize'
-                            OR
-            self.cache['monitor_metric'] = 'MSE'
-            self.cache['metric_direction'] = 'minimize'
-                            OR
-                    to save latest model
-            self.cache['monitor_metric'] = 'time'
-            self.cache['metric_direction'] = 'maximize'
-        2. Set new log_headers based on what is returned by get() method
-            of your implementation of easytorch.metrics.ETMetrics and easytorch.metrics.ETAverages class:
-            For example, the default implementation is:
-            - The get method of easytorch.metrics.ETAverages class returns the average loss value.
-            - The get method of easytorch.metrics.Prf1a returns Precision,Recall,F1,Accuracy
-            - so Default heade is [Loss,Precision,Recall,F1,Accuracy]
-        3. Set new log_dir based on different experiment versions on each datasets as per info. received from arguments.
-        """
-        self.cache['log_header'] = 'Loss,Precision,Recall,F1,Accuracy'
+        r"""What scores you want to plot."""
+        r"""By default it plots Loss,Accuracy,F1,Precision,Recall."""
+        self.cache['log_header'] = 'Loss,Accuracy,F1,Precision,Recall'
+
+        r"""This is for best model selection: """
+        r"""It tells which metrics to monitor and either to maximize(F1 score), minimize(MSE)"""
         self.cache.update(monitor_metric='f1', metric_direction='maximize')
 
     def save_if_better(self, epoch, metrics):
